@@ -6,7 +6,7 @@ import os
 class Config(object):
     FLASK_DEBUG = os.environ.get("FLASK_DEBUG", default=False)
     ID = os.environ.get("ID", default=None)
-    PORT = "5000"
+    DEFAULT_PORT = "5000"
     CORS_HEADERS = "Content-Type"
     UPLOAD_FOLDER = "./uploads"
     WORKFLOWS_DATA_FOLDER = "./data_workflows/"
@@ -19,7 +19,7 @@ class ProdConfig(Config):
     ORIGINS = ["https://geode-solutions.com", "https://next.geode-solutions.com"]
     MINUTES_BEFORE_TIMEOUT = "5"
     SECONDS_BETWEEN_SHUTDOWNS = "150"
-    DATA_FOLDER = "/data/"
+    DEFAULT_DATA_FOLDER_PATH = "/data/"
 
 
 class DevConfig(Config):
@@ -27,4 +27,4 @@ class DevConfig(Config):
     ORIGINS = "http://localhost:3000"
     MINUTES_BEFORE_TIMEOUT = "1000"
     SECONDS_BETWEEN_SHUTDOWNS = "60"
-    DATA_FOLDER = "./data/"
+    DEFAULT_DATA_FOLDER_PATH = "./data/"
